@@ -110,6 +110,13 @@ extern int _zbar_verbosity;
             ZFLUSH                                                      \
         }                                                               \
     } while(0)
+#  define zwprintf(level, format, args...) do {                         \
+        if(_zbar_verbosity >= level) {                                  \
+            fprintf(stderr, "%s: ", __func__);                          \
+            fwprintf(stderr, format, ##args);                           \
+            ZFLUSH                                                      \
+        }                                                               \
+    } while(0)
 # else
 #  define zprintf(level, format, ...) do {                              \
         if(_zbar_verbosity >= level) {                                  \
@@ -117,6 +124,13 @@ extern int _zbar_verbosity;
             ZFLUSH                                                      \
         }                                                               \
     } while(0)
+#  define zwprintf(level, format, ...) do {                             \
+        if(_zbar_verbosity >= level) {                                  \
+            fprintf(stderr, "%s: ", __func__);                          \
+            fwprintf(stderr, format, ##__VA_ARGS__);                    \
+            ZFLUSH                                                      \
+        }                                                               \
+    } while(0)
 # endif
 
 #endif
